==> green-core-1.61.0.tgz: package/index.js <==
import "./chunks/chunk.4EWOQKZC.js";
import {
  GdsVideo
} from "./chunks/chunk.DBFF5KCR.js";
import {
  GdsSpacer
} from "./chunks/chunk.YAPDYZK6.js";
import {
  GdsTextarea
} from "./chunks/chunk.OSIUU4NF.js";
import {
  GdsTheme
} from "./chunks/chunk.C3ZGNKY3.js";
import {
  GdsSegmentedControl
} from "./chunks/chunk.WXBRUX3Q.js";
import "./chunks/chunk.TSDZQZBY.js";
import "./chunks/chunk.HOH7FXB5.js";
import {
  GdsSignal
} from "./chunks/chunk.NCZAYYNU.js";
import {
  GdsMask
} from "./chunks/chunk.S4DOMLSN.js";
import {
  GdsMenuButton
} from "./chunks/chunk.PBUUPCPL.js";
import {
  GdsImg
} from "./chunks/chunk.IS6GBDKU.js";
import {
  GdsInput
} from "./chunks/chunk.A2VYZXDP.js";
import "./chunks/chunk.VHLWBCJK.js";
import "./chunks/chunk.7GC6JLT5.js";
import "./chunks/chunk.BWVUFYGS.js";
import "./chunks/chunk.UWI652VF.js";
import {
  GdsLink
} from "./chunks/chunk.YRHYEHLO.js";
import "./chunks/chunk.3DCLPMWF.js";
import "./chunks/chunk.PIHOBV6J.js";
import {
  GdsGroupedList
} from "./chunks/chunk.ZTRXED5A.js";
import "./chunks/chunk.24TVX5F4.js";
import "./chunks/chunk.V7ZQ5N3U.js";
import "./chunks/chunk.YL55SGZC.js";
import "./chunks/chunk.US5K5OGQ.js";
import {
  GdsFormSummary
} from "./chunks/chunk.GYV7S25D.js";
import "./chunks/chunk.5HUS6CAH.js";
import {
  GdsText
} from "./chunks/chunk.B7X4UWIN.js";
import "./chunks/chunk.UEJZWDMS.js";
import {
  GdsGrid
} from "./chunks/chunk.H26SOC3M.js";
import {
  GdsFilterChips
} from "./chunks/chunk.3HGZ5B5Q.js";
import "./chunks/chunk.VHN4JEZC.js";
import "./chunks/chunk.MURVRI5G.js";
import {
  GdsFilterChip
} from "./chunks/chunk.M6S3B5GI.js";
import {
  GdsDatepicker
} from "./chunks/chunk.RTE75ZOU.js";
import "./chunks/chunk.ZLUN7573.js";
import "./chunks/chunk.ZPRYPXHB.js";
import "./chunks/chunk.UETDXCD6.js";
import "./chunks/chunk.Q2T57HE7.js";
import {
  GdsDropdown
} from "./chunks/chunk.HJBA7FLT.js";
import "./chunks/chunk.MI4A2C2A.js";
import "./chunks/chunk.QN5HFZCH.js";
import {
  GdsOption
} from "./chunks/chunk.FCB5VT3N.js";
import "./chunks/chunk.WTSBCGGH.js";
import "./chunks/chunk.C3ECHGX7.js";
import "./chunks/chunk.GYFUC5DX.js";
import {
  GdsMenuHeading
} from "./chunks/chunk.KEPXMMGX.js";
import "./chunks/chunk.ZAV6NFUL.js";
import {
  GdsDivider
} from "./chunks/chunk.Z334YLO4.js";
import "./chunks/chunk.DJ2OXJZN.js";
import "./chunks/chunk.ALFDKEVN.js";
import {
  GdsCard
} from "./chunks/chunk.QIE6QJ5O.js";
import {
  GdsCoachmark
} from "./chunks/chunk.I56S5AF3.js";
import {
  GdsContextMenu
} from "./chunks/chunk.5L6LO6VX.js";
import "./chunks/chunk.UF6IEONX.js";
import "./chunks/chunk.RL2KSWKV.js";
import {
  GdsMenuItem
} from "./chunks/chunk.P2BOEVHE.js";
import "./chunks/chunk.E62NOHQC.js";
import "./chunks/chunk.43JUKB53.js";
import "./chunks/chunk.ZJVOZRT5.js";
import "./chunks/chunk.2TK7RRAM.js";
import "./chunks/chunk.77RJTA43.js";
import "./chunks/chunk.SB4EVIRY.js";
import {
  GdsIcon
} from "./chunks/chunk.K6WND5FJ.js";
import "./chunks/chunk.CK2UGCPG.js";
import {
  GdsBadge
} from "./chunks/chunk.SGFAP56K.js";
import "./chunks/chunk.3M4XRCEF.js";
import {
  GdsFlex
} from "./chunks/chunk.WV7BXKV6.js";
import "./chunks/chunk.WFKUYHQY.js";
import {
  GdsContainer
} from "./chunks/chunk.W6E54X7P.js";
import "./chunks/chunk.H2KG3F2S.js";
import "./chunks/chunk.JGTSJ4J6.js";
import {
  GdsButton
} from "./chunks/chunk.BHWBJIPJ.js";
import "./chunks/chunk.TX64TTBN.js";
import "./chunks/chunk.MSDETVDW.js";
import "./chunks/chunk.Z3MHP5MN.js";
import "./chunks/chunk.WM7HBMMV.js";
import "./chunks/chunk.27SYD4ZG.js";
import "./chunks/chunk.U44LH2CF.js";
import "./chunks/chunk.TYGMNHNO.js";
import "./chunks/chunk.BYYROY6X.js";
import "./chunks/chunk.IYBYOHJ2.js";
import "./chunks/chunk.YO24ZYAD.js";
import "./chunks/chunk.LQSWYCMZ.js";
import {
  ScopedElementRegistry,
  VER_SUFFIX,
  gdsCustomElement,
  getScopedTagName,
  getUnscopedTagName,
  html,
  htmlTemplateTagFactory
} from "./chunks/chunk.MLXMQIEV.js";
import "./chunks/chunk.WVKINQII.js";
import "./chunks/chunk.DI23R63U.js";
import "./chunks/chunk.SEHSDSX2.js";
export {
  GdsBadge,
  GdsButton,
  GdsCard,
  GdsCoachmark,
  GdsContainer,
  GdsContextMenu,
  GdsDatepicker,
  GdsDivider,
  GdsDropdown,
  GdsFilterChip,
  GdsFilterChips,
  GdsFlex,
  GdsFormSummary,
  GdsGrid,
  GdsGroupedList,
  GdsIcon,
  GdsImg,
  GdsInput,
  GdsLink,
  GdsMask,
  GdsMenuButton,
  GdsMenuHeading,
  GdsMenuItem,
  GdsOption,
  GdsSegmentedControl,
  GdsSignal,
  GdsSpacer,
  GdsText,
  GdsTextarea,
  GdsTheme,
  GdsVideo,
  ScopedElementRegistry,
  VER_SUFFIX,
  gdsCustomElement,
  getScopedTagName,
  getUnscopedTagName,
  html,
  htmlTemplateTagFactory
};

==> green-core-1.62.0.tgz: package/index.js <==
import "./chunks/chunk.4EWOQKZC.js";
import {
  GdsVideo
} from "./chunks/chunk.42MDAP6X.js";
import {
  GdsSpacer
} from "./chunks/chunk.7NLM5ITX.js";
import {
  GdsTextarea
} from "./chunks/chunk.NLD74Y2D.js";
import {
  GdsTheme
} from "./chunks/chunk.F527BHGP.js";
import {
  GdsSegmentedControl
} from "./chunks/chunk.PJJSVZOK.js";
import "./chunks/chunk.TSDZQZBY.js";
import "./chunks/chunk.DNBRIHSH.js";
import {
  GdsSignal
} from "./chunks/chunk.ZFGPNYTO.js";
import {
  GdsMask
} from "./chunks/chunk.73JEK27O.js";
import {
  GdsMenuButton
} from "./chunks/chunk.6AF3XRTH.js";
import {
  GdsImg
} from "./chunks/chunk.QWWOLT5V.js";
import {
  GdsInput
} from "./chunks/chunk.6AQRJC23.js";
import {
  GdsLink
} from "./chunks/chunk.5UYAQERP.js";
import {
  GdsGroupedList
} from "./chunks/chunk.MH5UGJXC.js";
import "./chunks/chunk.24TVX5F4.js";
import "./chunks/chunk.V7ZQ5N3U.js";
import "./chunks/chunk.YL55SGZC.js";
import "./chunks/chunk.US5K5OGQ.js";
import {
  GdsFormSummary
} from "./chunks/chunk.GYV7S25D.js";
import "./chunks/chunk.5HUS6CAH.js";
import {
  GdsText
} from "./chunks/chunk.3W52UD6H.js";
import "./chunks/chunk.UEJZWDMS.js";
import {
  GdsGrid
} from "./chunks/chunk.UKR6SWJ2.js";
import {
  GdsFilterChips
} from "./chunks/chunk.XMAA7CU5.js";
import "./chunks/chunk.VHN4JEZC.js";
import "./chunks/chunk.MURVRI5G.js";
import {
  GdsFilterChip
} from "./chunks/chunk.MT7XFVN3.js";
import {
  GdsDatepicker
} from "./chunks/chunk.NWFUJWE6.js";
import "./chunks/chunk.ZLUN7573.js";
import "./chunks/chunk.ZPRYPXHB.js";
import "./chunks/chunk.UETDXCD6.js";
import "./chunks/chunk.NVK3KBQH.js";
import "./chunks/chunk.Q2T57HE7.js";
import {
  GdsDropdown
} from "./chunks/chunk.7LYVHSEG.js";
import "./chunks/chunk.MI4A2C2A.js";
import "./chunks/chunk.NHKCTJYM.js";
import {
  GdsOption
} from "./chunks/chunk.I757A54S.js";
import "./chunks/chunk.VZTV63IQ.js";
import "./chunks/chunk.PNB5RPI3.js";
import "./chunks/chunk.VHLWBCJK.js";
import "./chunks/chunk.NCKHK5PG.js";
import "./chunks/chunk.7GC6JLT5.js";
import "./chunks/chunk.NRNM3BUT.js";
import "./chunks/chunk.3DCLPMWF.js";
import "./chunks/chunk.PIHOBV6J.js";
import "./chunks/chunk.WTSBCGGH.js";
import "./chunks/chunk.C3ECHGX7.js";
import "./chunks/chunk.GYFUC5DX.js";
import {
  GdsMenuHeading
} from "./chunks/chunk.DJH7QFAN.js";
import "./chunks/chunk.ZAV6NFUL.js";
import {
  GdsDivider
} from "./chunks/chunk.5CEHJDND.js";
import "./chunks/chunk.DJ2OXJZN.js";
import "./chunks/chunk.ALFDKEVN.js";
import {
  GdsCard
} from "./chunks/chunk.7QPOP3BL.js";
import {
  GdsCoachmark
} from "./chunks/chunk.I56S5AF3.js";
import {
  GdsContextMenu
} from "./chunks/chunk.EKZSYRZR.js";
import "./chunks/chunk.UF6IEONX.js";
import "./chunks/chunk.EB3VGCXK.js";
import {
  GdsMenuItem
} from "./chunks/chunk.APDVCDJD.js";
import "./chunks/chunk.E62NOHQC.js";
import "./chunks/chunk.ZRKILGXZ.js";
import "./chunks/chunk.ZJVOZRT5.js";
import "./chunks/chunk.2TK7RRAM.js";
import "./chunks/chunk.HPSQUKF2.js";
import "./chunks/chunk.SB4EVIRY.js";
import {
  GdsIcon
} from "./chunks/chunk.K6WND5FJ.js";
import "./chunks/chunk.CK2UGCPG.js";
import {
  GdsBadge
} from "./chunks/chunk.PPMF6234.js";
import "./chunks/chunk.3M4XRCEF.js";
import {
  GdsFlex
} from "./chunks/chunk.WWSNXINM.js";
import "./chunks/chunk.WFKUYHQY.js";
import {
  GdsContainer
} from "./chunks/chunk.RGTKMLGE.js";
import "./chunks/chunk.H2KG3F2S.js";
import "./chunks/chunk.JGTSJ4J6.js";
import {
  GdsButton
} from "./chunks/chunk.QLHOYAX6.js";
import "./chunks/chunk.TX64TTBN.js";
import "./chunks/chunk.JVDRTWPP.js";
import "./chunks/chunk.V56VPSWH.js";
import "./chunks/chunk.WM7HBMMV.js";
import "./chunks/chunk.UBTUHHC7.js";
import "./chunks/chunk.3M24Q4NP.js";
import "./chunks/chunk.TYGMNHNO.js";
import "./chunks/chunk.YO24ZYAD.js";
import "./chunks/chunk.4RMUKKUH.js";
import "./chunks/chunk.IYBYOHJ2.js";
import "./chunks/chunk.LQSWYCMZ.js";
import {
  ScopedElementRegistry,
  VER_SUFFIX,
  gdsCustomElement,
  getScopedTagName,
  getUnscopedTagName,
  html,
  htmlTemplateTagFactory
} from "./chunks/chunk.MLXMQIEV.js";
import "./chunks/chunk.WVKINQII.js";
import "./chunks/chunk.DI23R63U.js";
import "./chunks/chunk.SEHSDSX2.js";
export {
  GdsBadge,
  GdsButton,
  GdsCard,
  GdsCoachmark,
  GdsContainer,
  GdsContextMenu,
  GdsDatepicker,
  GdsDivider,
  GdsDropdown,
  GdsFilterChip,
  GdsFilterChips,
  GdsFlex,
  GdsFormSummary,
  GdsGrid,
  GdsGroupedList,
  GdsIcon,
  GdsImg,
  GdsInput,
  GdsLink,
  GdsMask,
  GdsMenuButton,
  GdsMenuHeading,
  GdsMenuItem,
  GdsOption,
  GdsSegmentedControl,
  GdsSignal,
  GdsSpacer,
  GdsText,
  GdsTextarea,
  GdsTheme,
  GdsVideo,
  ScopedElementRegistry,
  VER_SUFFIX,
  gdsCustomElement,
  getScopedTagName,
  getUnscopedTagName,
  html,
  htmlTemplateTagFactory
};
